TemplateException class

Exception thrown when template parsing or rendering fails.

Implemented types

Constructors

TemplateException(String message, [String? details])
Creates a template exception with the given message.
const

Properties

details String?
Optional details about the location of the error.
final
hashCode int
The hash code for this object.
no setterinherited
message String
The error message describing what went wrong.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited