PdfGenerationException class
Exception thrown when PDF generation fails.
- Implemented types
Constructors
- PdfGenerationException(String message, {PdfGenerationPhase phase = PdfGenerationPhase.unknown, Object? cause})
-
Creates a PDF generation exception.
const
Properties
- cause → Object?
-
The underlying error, if any.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
The error message describing what went wrong.
final
- phase → PdfGenerationPhase
-
The phase during which the error occurred.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited